==> youtubedl-gui_4.4.orig.tar.xz: youtubedl-gui-4.4/locales/ytdl-gui_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>QCoreApplication</name>
    <message>
        <source>Cancel download in progress?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Saving and converting...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Progress</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Youtube Downloader</source>
        <translation>Video-Downloader</translation>
    </message>
    <message>
        <source>Invalid argument in config file:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>invalid argument</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>out of range</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>undefined error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid argument in config file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Download Succeeded</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>[INFO] Yt-dlp command: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>[ERROR] QProcess failed with error code: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select a folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed! Recheck input for errors. If the url you provided is correct, try with other resolutions or formats.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>downloadStatus</name>
    <message>
        <source>Dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Downloading...</source>
        <translation>Download läuft...</translation>
    </message>
</context>
<context>
    <name>ytdl</name>
    <message>
        <source>ytdl</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Music&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio</source>
        <translation></translation>
    </message>
    <message>
        <source>Quality:</source>
        <translation>Audioqualität:</translation>
    </message>
    <message>
        <source>Best</source>
        <translation>Beste</translation>
    </message>
    <message>
        <source>Good</source>
        <translation>Gut</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Low</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Format:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AAC</source>
        <translation></translation>
    </message>
    <message>
        <source>OGG</source>
        <translation></translation>
    </message>
    <message>
        <source>MP3</source>
        <translation></translation>
    </message>
    <message>
        <source>OPUS</source>
        <translation></translation>
    </message>
    <message>
        <source>WAV</source>
        <translation></translation>
    </message>
    <message>
        <source>Video</source>
        <translation></translation>
    </message>
    <message>
        <source>Max Resolution:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>4K</source>
        <translation></translation>
    </message>
    <message>
        <source>1440p</source>
        <translation></translation>
    </message>
    <message>
        <source>1080p</source>
        <translation></translation>
    </message>
    <message>
        <source>720p</source>
        <translation></translation>
    </message>
    <message>
        <source>480p</source>
        <translation></translation>
    </message>
    <message>
        <source>360p</source>
        <translation></translation>
    </message>
    <message>
        <source>Preferred Format:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>3GP</source>
        <translation></translation>
    </message>
    <message>
        <source>FLV</source>
        <translation></translation>
    </message>
    <message>
        <source>MP4</source>
        <translation></translation>
    </message>
    <message>
        <source>WEBM</source>
        <translation></translation>
    </message>
    <message>
        <source>Enter URL:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Playlist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Browse...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Defaults</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Herunterladen</translation>
    </message>
</context>
</TS>

==> youtubedl-gui_4.4.1.orig.tar.xz: youtubedl-gui-4.4.1/locales/ytdl-gui_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>QCoreApplication</name>
    <message>
        <source>Cancel download in progress?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Saving and converting...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Progress</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Youtube Downloader</source>
        <translation>Video-Downloader</translation>
    </message>
    <message>
        <source>Invalid argument in config file:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>invalid argument</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>out of range</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>undefined error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid argument in config file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Download Succeeded</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>[INFO] Yt-dlp command: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>[ERROR] QProcess failed with error code: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select a folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed! Recheck input for errors. If the url you provided is correct, try with other resolutions or formats.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>downloadStatus</name>
    <message>
        <source>Dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Downloading...</source>
        <translation>Download läuft...</translation>
    </message>
</context>
<context>
    <name>ytdl</name>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Music&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio</source>
        <translation></translation>
    </message>
    <message>
        <source>Quality:</source>
        <translation>Audioqualität:</translation>
    </message>
    <message>
        <source>Best</source>
        <translation>Beste</translation>
    </message>
    <message>
        <source>Good</source>
        <translation>Gut</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Low</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Format:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AAC</source>
        <translation></translation>
    </message>
    <message>
        <source>OGG</source>
        <translation></translation>
    </message>
    <message>
        <source>MP3</source>
        <translation></translation>
    </message>
    <message>
        <source>OPUS</source>
        <translation></translation>
    </message>
    <message>
        <source>WAV</source>
        <translation></translation>
    </message>
    <message>
        <source>Video</source>
        <translation></translation>
    </message>
    <message>
        <source>Max Resolution:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>4K</source>
        <translation></translation>
    </message>
    <message>
        <source>1440p</source>
        <translation></translation>
    </message>
    <message>
        <source>1080p</source>
        <translation></translation>
    </message>
    <message>
        <source>720p</source>
        <translation></translation>
    </message>
    <message>
        <source>480p</source>
        <translation></translation>
    </message>
    <message>
        <source>360p</source>
        <translation></translation>
    </message>
    <message>
        <source>Preferred Format:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>3GP</source>
        <translation></translation>
    </message>
    <message>
        <source>FLV</source>
        <translation></translation>
    </message>
    <message>
        <source>MP4</source>
        <translation></translation>
    </message>
    <message>
        <source>WEBM</source>
        <translation></translation>
    </message>
    <message>
        <source>Enter URL:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Playlist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Browse...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Defaults</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Herunterladen</translation>
    </message>
    <message>
        <source>Yt Downloader</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Best quality audio, the file will be bigger than with other quality levels.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Lower quality audio, the file will be smaller than with other quality levels.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>(Recommended for Apple’s systems) Small files but not universally supported and proprietary</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>(Recommended for open-source systems) Small files and good performances but not supported everywhere</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>(Recommended for most system) Best compatibility and good audio quality</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Better audio reproduction but large files and not supported everywhere</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Better audio reproduction but really large files</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
